searchNodes=[{"doc":"An interval represents the points between two endpoints. The interval can be empty. The empty interval is never contained in any other interval, and itself contains no points. It can be left and/or right unbounded, in which case it contains all points in the unbounded direction. A fully unbounded interval contains all other intervals, except the empty interval. Features The key features of this library are Common interval operations built in are intersection/2 union/2 overlaps?/2 contains?/2 partition/2 adjacent? empty? unbounded? Built in support for intervals containing Integer Float Date DateTime Decimal Also implements Ecto.Type Jason.Encoder Interval Notation Throughout the documentation and comments, you'll see a notation for writing about intervals. As this library is inspired by the functionality in PostgreSQL's range types, we align ourselves with it's notation choice and borrow it ( https://www.postgresql.org/docs/current/rangetypes.html ) This notation is also described in ISO 31-11. [ left - inclusive , right - inclusive ] ( left - exclusive , right - exclusive ) [ left - inclusive , right - exclusive ) ( left - exclusive , right - inclusive ] :empty An unbounded interval is written by omitting the bound type and point: , right - exclusive ) [ left - inclusive , When specifying bound types we sometimes leave the point out and just write the left and right bounds: [ ] ( ) ( ] [ ) ( ) [ ] Types of Interval This library ships with a few different types of intervals. The built-in intervals are: Interval.Date containing points of type Date Interval.DateTime containing points of type DateTime Interval.Float containing points of type Float Interval.Integer containing points of type Integer Interval.Decimal containing points of type Decimal (See https://hexdocs.pm/decimal/2.0.0 ) However, you can quite easily implement an interval by implementing the Interval.Behaviour . The easiest way to do so, is by using the Interval.__using__ macro: defmodule MyInterval do use Interval , type : MyType , discrete : false end You must implement a few functions defined in Interval.Behaviour . Once that's done, all operations available in the Interval module (like interesection, union, overlap etc) will work on your interval struct. An obvious usecase for this would be to implement an interval that works with the https://hexdocs.pm/decimal library. Discrete vs Continuous intervals Depending on the behaviour you want from your interval, it is either said to be discrete or continuous. A discrete interval represents a set of finite points (like integers). A continuous interval can be said to represent the infinite number of points between two endpoints (like an interval between two floats). With discrete points, it is possible to define what the next and previous point is, and we normalise these intervals to the bound type [) . The distinction between a discrete and continuous interval is important because the two behave slightly different in some of the library functions. A discrete interval is adjacent to another discrete interval, if there is no points between the two interval. Contrast this to continuous intervals of real numbers where there is always an infinite number of real numbers between two distinct real numbers, and so continuous intervals are only said to be adjacent to each other if they include the same point, and one point is inclusive where the other is exclusive. Where relevant, the function documentation will mention the differences between discrete and continuous intervals. Create an Interval See new/1 . Normalization When creating an interval through new/1 , it will get normalized so that intervals that represents the same points, are also represented in the same way in the struct. This allows you to compare two intervals for equality by using == (and using pattern matching). It is therefore not recommended to modify an interval struct directly, but instead do so by using one of the functions that modify the interval. An interval is said to be empty if it spans zero points. The normalized form of an empty interval is the special interval struct where left and right is set to :empty , however a non-normalized empty struct will still correctly report empty via the empty?/1 function.","ref":"Interval.html","title":"Interval","type":"module"},{"doc":"Define an interval struct of a specific point type. Support for Ecto.Type and the Postgrex.Range can be automatically generated by specifying ecto_type: &lt;type&gt; when use ing. Options type - The internal point type in this interval. required discrete - Is this interval discrete? default: false jason_encoder - Should it include Jason.Encoder implementation? default: true Examples defmodule MyInterval do use Interval , type : MyType , discrete : false end","ref":"Interval.html#__using__/1","title":"Interval.__using__/1","type":"macro"},{"doc":"Is the interval a adjacent to b , to the left of b . a is adjacent to b left of b , if a and b do not overlap, and there are no points between a.right and b.left . # a: [---) # b: [---) # r: true # a: [---] # b: [---] # r: false (overlaps) # a: (---) # b: (---) # r: false (points exist between a.right and b.left) Examples iex&gt; adjacent_left_of? ( new ( module : Interval.Integer , left : 1 , right : 2 ) , new ( module : Interval.Integer , left : 2 , right : 3 ) ) true iex&gt; adjacent_left_of? ( new ( module : Interval.Integer , left : 1 , right : 3 ) , new ( module : Interval.Integer , left : 2 , right : 4 ) ) false iex&gt; adjacent_left_of? ( new ( module : Interval.Integer , left : 3 , right : 4 ) , new ( module : Interval.Integer , left : 1 , right : 2 ) ) false iex&gt; adjacent_left_of? ( new ( module : Interval.Integer , right : 2 , bounds : &quot;[]&quot; ) , new ( module : Interval.Integer , left : 3 ) ) true","ref":"Interval.html#adjacent_left_of?/2","title":"Interval.adjacent_left_of?/2","type":"function"},{"doc":"Is the interval a adjacent to b , to the right of b . a is adjacent to b right of b , if a and b do not overlap, and there are no points between a.left and b.right . # a: [---) # b: [---) # r: true # a: [---) # b: [---] # r: false (overlaps) # a: (---) # b: (---) # r: false (points exist between a.left and b.right) Examples iex&gt; adjacent_right_of? ( new ( module : Interval.Integer , left : 2 , right : 3 ) , new ( module : Interval.Integer , left : 1 , right : 2 ) ) true iex&gt; adjacent_right_of? ( new ( module : Interval.Integer , left : 1 , right : 3 ) , new ( module : Interval.Integer , left : 2 , right : 4 ) ) false iex&gt; adjacent_right_of? ( new ( module : Interval.Integer , left : 1 , right : 2 ) , new ( module : Interval.Integer , left : 3 , right : 4 ) ) false iex&gt; adjacent_right_of? ( new ( module : Interval.Integer , left : 3 ) , new ( module : Interval.Integer , right : 2 , bounds : &quot;]&quot; ) ) true","ref":"Interval.html#adjacent_right_of?/2","title":"Interval.adjacent_right_of?/2","type":"function"},{"doc":"Does a contain the point x ? Examples iex&gt; contains_point? ( new ( module : Interval.Integer , left : 1 , right : 2 ) , 0 ) false iex&gt; contains_point? ( new ( module : Interval.Integer , left : 1 , right : 2 ) , 1 ) true","ref":"Interval.html#contains_point?/2","title":"Interval.contains_point?/2","type":"function"},{"doc":"Does a contain b ? a contains b of all points in b is also in a . For an interval a to contain an interval b , all points in b must be contained in a : # a: [-------] # b: [---] # r: true # a: [---] # b: [---] # r: true # a: [---] # b: (---) # r: true # a: (---) # b: [---] # r: false # a: [---] # b: [-------] # r: false This means that a.left is less than b.left (or unbounded), and a.right is greater than b.right (or unbounded) If a and b 's point match, then b is &quot;in&quot; a if a and b share bound types. E.g. if a.left and b.left matches, then a contains b if both a and b 's left is inclusive or exclusive. If either of b endpoints are unbounded, then a only contains b if the corresponding endpoint in a is also unbounded. Examples iex&gt; contains? ( new ( module : Interval.Integer , left : 1 , right : 2 ) , new ( module : Interval.Integer , left : 1 , right : 2 ) ) true iex&gt; contains? ( new ( module : Interval.Integer , left : 1 , right : 3 ) , new ( module : Interval.Integer , left : 2 , right : 3 ) ) true iex&gt; contains? ( new ( module : Interval.Integer , left : 2 , right : 3 ) , new ( module : Interval.Integer , left : 1 , right : 4 ) ) false iex&gt; contains? ( new ( module : Interval.Integer , left : 1 , right : 3 ) , new ( module : Interval.Integer , left : 1 , right : 2 ) ) true iex&gt; contains? ( new ( module : Interval.Integer , left : 1 , right : 2 , bounds : &quot;()&quot; ) , new ( module : Interval.Integer , left : 1 , right : 3 ) ) false iex&gt; contains? ( new ( module : Interval.Integer , right : 1 ) , new ( module : Interval.Integer , left : 0 , right : 1 ) ) true","ref":"Interval.html#contains?/2","title":"Interval.contains?/2","type":"function"},{"doc":"Is the interval empty? An empty interval is an interval that represents no points. Any interval containing no points is considered empty. An unbounded interval is never empty. For continuous points, the interval is empty when the left and right points are identical, and the point is not included in the interval. For discrete points, the interval is empty when the left and right point isn't inclusive, and there are no points between the left and right point. Examples iex&gt; empty? ( new ( module : Interval.Integer , left : 0 , right : 0 ) ) true iex&gt; empty? ( new ( module : Interval.Float , left : 1.0 ) ) false iex&gt; empty? ( new ( module : Interval.Integer , left : 1 , right : 2 ) ) false","ref":"Interval.html#empty?/1","title":"Interval.empty?/1","type":"function"},{"doc":"Is the interval left-inclusive? The interval is left-inclusive if the left endpoint value is included in the interval. Note Discrete intervals (like Interval.Integer and Interval.Date ) are always normalized to be left-inclusive right-exclusive ( [) ). iex&gt; inclusive_left? ( new ( module : Interval.Float , left : 1.0 , right : 2.0 , bounds : &quot;[]&quot; ) ) true iex&gt; inclusive_left? ( new ( module : Interval.Float , left : 1.0 , right : 2.0 , bounds : &quot;[)&quot; ) ) true iex&gt; inclusive_left? ( new ( module : Interval.Float , left : 1.0 , right : 2.0 , bounds : &quot;()&quot; ) ) false","ref":"Interval.html#inclusive_left?/1","title":"Interval.inclusive_left?/1","type":"function"},{"doc":"Is the interval right-inclusive? The interval is right-inclusive if the right endpoint value is included in the interval. Note Discrete intervals (like Interval.Integer and Interval.Date ) are always normalized to be left-inclusive right-exclusive ( [) ). iex&gt; inclusive_right? ( new ( module : Interval.Float , left : 1.0 , right : 2.0 , bounds : &quot;[]&quot; ) ) true iex&gt; inclusive_right? ( new ( module : Interval.Float , left : 1.0 , right : 2.0 , bounds : &quot;[)&quot; ) ) false iex&gt; inclusive_right? ( new ( module : Interval.Float , left : 1.0 , right : 2.0 , bounds : &quot;()&quot; ) ) false","ref":"Interval.html#inclusive_right?/1","title":"Interval.inclusive_right?/1","type":"function"},{"doc":"Compute the intersection between a and b . The intersection contains all of the points that are both in a and b . If either a or b are empty, the returned interval will be empty. # a: [----] # b: [----] # r: [-] # a: (----) # b: (----) # r: (-) # a: [----) # b: [----) # r: [-) Examples: Discrete: # a: [----) # b: [----) # c: [-) iex&gt; intersection ( new ( module : Interval.Integer , left : 1 , right : 3 ) , new ( module : Interval.Integer , left : 2 , right : 4 ) ) new ( module : Interval.Integer , left : 2 , right : 3 ) Continuous: # a: [----) # b: [----) # c: [-) iex&gt; intersection ( new ( module : Interval.Float , left : 1.0 , right : 3.0 ) , new ( module : Interval.Float , left : 2.0 , right : 4.0 ) ) new ( module : Interval.Float , left : 2.0 , right : 3.0 ) # a: (----) # b: (----) # c: (-) iex&gt; intersection ( ...&gt; new ( module : Interval.Float , left : 1.0 , right : 3.0 , bounds : &quot;()&quot; ) , ...&gt; new ( module : Interval.Float , left : 2.0 , right : 4.0 , bounds : &quot;()&quot; ) ...&gt; ) new ( module : Interval.Float , left : 2.0 , right : 3.0 , bounds : &quot;()&quot; ) # a: [-----) # b: [------- # c: [---) iex&gt; intersection ( new ( module : Interval.Float , left : 1.0 , right : 3.0 ) , new ( module : Interval.Float , left : 2.0 ) ) new ( module : Interval.Float , left : 2.0 , right : 3.0 )","ref":"Interval.html#intersection/2","title":"Interval.intersection/2","type":"function"},{"doc":"Return the left point. This function always returns nil when no point exist. Use the functions empty?/1 , inclusive_left?/1 and unbounded_left?/1 to check for the meaning of the point. Example iex&gt; left ( new ( module : Interval.Integer , left : 1 , right : 2 ) ) 1","ref":"Interval.html#left/1","title":"Interval.left/1","type":"function"},{"doc":"Create a new interval. Options module The interval implementation to use. When calling new/1 from a Interval.Behaviour this is inferred. left The left (or lower) endpoint of the interval right The right (or upper) endpoint of the interval bounds The bound mode to use. Defaults to &quot;[)&quot; A nil ( left or right ) endpoint is considered unbounded. The endpoint will also be considered unbounded if the bounds is explicitly set as unbounded. A special value :empty can be given to left and right to construct an empty interval. Bounds The bounds options contains the left and right bound mode to use. The bound can be inclusive, exclusive or unbounded. The following valid bound values are supported: &quot;[)&quot; left-inclusive, right-exclusive (default) &quot;(]&quot; left-exclusive, right-inclusive &quot;[]&quot; left-inclusive, right-inclusive &quot;()&quot; left-exclusive, right-exclusive &quot;)&quot; left-unbounded, right-exclusive &quot;]&quot; left-unbounded, right-inclusive &quot;(&quot; left-exclusive, right-unbounded &quot;[&quot; left-inclusive, right-unbounded Examples iex&gt; new ( module : Interval.Integer ) iex&gt; new ( module : Interval.Integer , left : :empty , right : :empty ) iex&gt; new ( module : Interval.Integer , left : 1 ) iex&gt; new ( module : Interval.Integer , left : 1 , right : 1 , bounds : &quot;[]&quot; ) iex&gt; new ( module : Interval.Integer , left : 10 , right : 20 , bounds : &quot;()&quot; )","ref":"Interval.html#new/1","title":"Interval.new/1","type":"function"},{"doc":"Does a overlap with b ? a overlaps with b if any point in a is also in b . # a: [---) # b: [---) # r: true # a: [---) # b: [---) # r: false # a: [---] # b: [---] # r: true # a: (---) # b: (---) # r: false # a: [---) # b: [---) # r: false Examples # [--a--) # [--b--) iex&gt; overlaps? ( new ( module : Interval.Integer , left : 1 , right : 3 ) , new ( module : Interval.Integer , left : 2 , right : 4 ) ) true # [--a--) # [--b--) iex&gt; overlaps? ( new ( module : Interval.Integer , left : 1 , right : 3 ) , new ( module : Interval.Integer , left : 3 , right : 5 ) ) false # [--a--] # [--b--] iex&gt; overlaps? ( new ( module : Interval.Integer , left : 1 , right : 3 ) , new ( module : Interval.Integer , left : 2 , right : 4 ) ) true # (--a--) # (--b--) iex&gt; overlaps? ( new ( module : Interval.Integer , left : 1 , right : 3 ) , new ( module : Interval.Integer , left : 3 , right : 5 ) ) false # [--a--) # [--b--) iex&gt; overlaps? ( new ( module : Interval.Integer , left : 1 , right : 2 ) , new ( module : Interval.Integer , left : 3 , right : 4 ) ) false","ref":"Interval.html#overlaps?/2","title":"Interval.overlaps?/2","type":"function"},{"doc":"Partition an interval a into 3 intervals using x : The interval with all points from a &lt; x The interval with just x The interval with all points from a &gt; x If x is not in a this function returns an empty list. Examples iex&gt; partition ( new ( module : Interval.Integer , left : 1 , right : 5 , bounds : &quot;[]&quot; ) , 3 ) [ new ( module : Interval.Integer , left : 1 , right : 3 , bounds : &quot;[)&quot; ) , new ( module : Interval.Integer , left : 3 , right : 3 , bounds : &quot;[]&quot; ) , new ( module : Interval.Integer , left : 3 , right : 5 , bounds : &quot;(]&quot; ) ] iex&gt; partition ( new ( module : Interval.Integer , left : 1 , right : 5 ) , - 10 ) [ ]","ref":"Interval.html#partition/2","title":"Interval.partition/2","type":"function"},{"doc":"Return the right point. This function always returns nil when no point exist. Use the functions empty?/1 , inclusive_right?/1 and unbounded_right?/1 to check for the meaning of the point. Example iex&gt; right ( new ( module : Interval.Integer , left : 1 , right : 2 ) ) 2","ref":"Interval.html#right/1","title":"Interval.right/1","type":"function"},{"doc":"","ref":"Interval.html#size/1","title":"Interval.size/1","type":"function"},{"doc":"Is a strictly left of b . a is strictly left of b if no point in a is in b , and all points in a is left (&lt;) of all points in b . Examples # a: [---) # b: [---) # r: true # a: [---) # b: [---) # r: true # a: [---) # b: [---) # r: false (overlaps) iex&gt; strictly_left_of? ( new ( module : Interval.Integer , left : 1 , right : 2 ) , new ( module : Interval.Integer , left : 3 , right : 4 ) ) true iex&gt; strictly_left_of? ( new ( module : Interval.Integer , left : 1 , right : 3 ) , new ( module : Interval.Integer , left : 2 , right : 4 ) ) false iex&gt; strictly_left_of? ( new ( module : Interval.Integer , left : 3 , right : 4 ) , new ( module : Interval.Integer , left : 1 , right : 2 ) ) false","ref":"Interval.html#strictly_left_of?/2","title":"Interval.strictly_left_of?/2","type":"function"},{"doc":"Is a strictly right of b . a is strictly right of b if no point in a is in b , and all points in a is right (&gt;) of all points in b . Examples # a: [---) # b: [---) # r: true # a: [---) # b: [---) # r: true # a: [---) # b: [---) # r: false (overlaps) iex&gt; strictly_right_of? ( new ( module : Interval.Integer , left : 1 , right : 2 ) , new ( module : Interval.Integer , left : 3 , right : 4 ) ) false iex&gt; strictly_right_of? ( new ( module : Interval.Integer , left : 1 , right : 3 ) , new ( module : Interval.Integer , left : 2 , right : 4 ) ) false iex&gt; strictly_right_of? ( new ( module : Interval.Integer , left : 3 , right : 4 ) , new ( module : Interval.Integer , left : 1 , right : 2 ) ) true","ref":"Interval.html#strictly_right_of?/2","title":"Interval.strictly_right_of?/2","type":"function"},{"doc":"Convert an Interval.t/0 to a map. The returned map contains the struct module used for the interval in the type key, so that it is possible to reconstruct the interval from the map.","ref":"Interval.html#to_map/1","title":"Interval.to_map/1","type":"function"},{"doc":"Check if the interval is left-unbounded. The interval is left-unbounded if all points left of the right bound is included in this interval. Examples iex&gt; unbounded_left? ( new ( module : Interval.Integer ) ) true iex&gt; unbounded_left? ( new ( module : Interval.Integer , right : 2 ) ) true iex&gt; unbounded_left? ( new ( module : Interval.Integer , left : 1 , right : 2 ) ) false","ref":"Interval.html#unbounded_left?/1","title":"Interval.unbounded_left?/1","type":"function"},{"doc":"Check if the interval is right-unbounded. The interval is right-unbounded if all points right of the left bound is included in this interval. Examples iex&gt; unbounded_right? ( new ( module : Interval.Integer , right : 1 ) ) false iex&gt; unbounded_right? ( new ( module : Interval.Integer ) ) true iex&gt; unbounded_right? ( new ( module : Interval.Integer , left : 1 ) ) true","ref":"Interval.html#unbounded_right?/1","title":"Interval.unbounded_right?/1","type":"function"},{"doc":"Computes the union of a and b . The union contains all of the points that are either in a or b . If either a or b are empty, the returned interval will be empty. # a: [---) # b: [---) # r: [-----) Examples # [--A--) # [--B--) # [----C----) iex&gt; union ( new ( module : Interval.Integer , left : 1 , right : 3 ) , new ( module : Interval.Integer , left : 2 , right : 4 ) ) new ( module : Interval.Integer , left : 1 , right : 4 ) # [-A-) # [-B-) # [---C---) iex&gt; union ( new ( module : Interval.Integer , left : 1 , right : 2 ) , new ( module : Interval.Integer , left : 2 , right : 3 ) ) new ( module : Interval.Integer , left : 1 , right : 3 ) iex&gt; union ( new ( module : Interval.Integer , left : 1 , right : 2 ) , new ( module : Interval.Integer , left : 3 , right : 4 ) ) new ( module : Interval.Integer , left : 0 , right : 0 )","ref":"Interval.html#union/2","title":"Interval.union/2","type":"function"},{"doc":"The bound type of an endpoint.","ref":"Interval.html#t:bound/0","title":"Interval.bound/0","type":"type"},{"doc":"A point in an interval.","ref":"Interval.html#t:point/0","title":"Interval.point/0","type":"type"},{"doc":"Shorthand for t(any())","ref":"Interval.html#t:t/0","title":"Interval.t/0","type":"type"},{"doc":"An interval struct, representing all points between two endpoints. The struct has two fields: left and right , representing the left (lower) and right (upper) points in the interval. If either left or right is set to :empty , the both must be set to :empty . The specific struct type depends on the interval implementation, but the left and right field is always present, all will be manipulated by the Interval module regardless of the interval implementation.","ref":"Interval.html#t:t/1","title":"Interval.t/1","type":"type"},{"doc":"Defines the Interval behaviour. You'll usually want to use this behaviour by using use Interval , type : MyType In your own interval modules, instead of defining the behaviour directly.","ref":"Interval.Behaviour.html","title":"Interval.Behaviour","type":"behaviour"},{"doc":"Is this implementation of an interval considered discrete? The interval is implicitly continuous if not discrete.","ref":"Interval.Behaviour.html#c:discrete?/0","title":"Interval.Behaviour.discrete?/0","type":"callback"},{"doc":"Create a new Interval.t/0","ref":"Interval.Behaviour.html#c:new/1","title":"Interval.Behaviour.new/1","type":"callback"},{"doc":"Compare two points, returning if a == b , a &gt; b or a &lt; b .","ref":"Interval.Behaviour.html#c:point_compare/2","title":"Interval.Behaviour.point_compare/2","type":"callback"},{"doc":"Step a discrete point n steps. If n is negative, the point is stepped backwards. For integers this is simply addition ( point + n )","ref":"Interval.Behaviour.html#c:point_step/2","title":"Interval.Behaviour.point_step/2","type":"callback"},{"doc":"Is the given argument a valid point in this Interval implementation.","ref":"Interval.Behaviour.html#c:point_valid?/1","title":"Interval.Behaviour.point_valid?/1","type":"callback"},{"doc":"Return the &quot;size&quot; of the interval. The returned value depends on the interval implementation used. For Discrete Intervals For discrete point types, the size represents the number of elements the interval contains. I.e. for Date the size is the number of Date structs the interval can be said to &quot;contain&quot; (the number of days) Examples iex&gt; size ( new ( module : Interval.Integer , left : 1 , right : 1 , bounds : &quot;[]&quot; ) ) 1 iex&gt; size ( new ( module : Interval.Integer , left : 1 , right : 3 , bounds : &quot;[)&quot; ) ) 2 # Note that this interval will be normalized to an empty interval # due to the bounds: iex&gt; size ( new ( module : Interval.Integer , left : 1 , right : 2 , bounds : &quot;()&quot; ) ) 0 For Continuous Intervals For continuous intervals, the size is reported as the difference between the left and right points. Examples # The size of the interval `[1.0, 5.0)` is also 4: iex&gt; size ( new ( module : Interval.Float , left : 1.0 , right : 5.0 , bounds : &quot;[)&quot; ) ) 4.0 # And likewise, so is the size of `[1.0, 5.0]` (note the bound change) iex&gt; size ( new ( module : Interval.Float , left : 1.0 , right : 5.0 , bounds : &quot;[]&quot; ) ) 4.0 # Exactly one point contained in this continuous interval, # so technically not empty, but it also has zero size. iex&gt; size ( new ( module : Interval.Float , left : 1.0 , right : 1.0 , bounds : &quot;[]&quot; ) ) 0.0 # Empty continuous interval iex&gt; size ( new ( module : Interval.Float , left : 1.0 , right : 1.0 , bounds : &quot;()&quot; ) ) 0.0","ref":"Interval.Behaviour.html#c:size/1","title":"Interval.Behaviour.size/1","type":"callback"},{"doc":"","ref":"Interval.Behaviour.html#t:new_opt/0","title":"Interval.Behaviour.new_opt/0","type":"type"},{"doc":"","ref":"Interval.Behaviour.html#t:new_opts/0","title":"Interval.Behaviour.new_opts/0","type":"type"},{"doc":"Represents a discrete interval containing Elixir.Date","ref":"Interval.Date.html","title":"Interval.Date","type":"module"},{"doc":"Callback implementation for Interval.Behaviour.discrete?/0 .","ref":"Interval.Date.html#discrete?/0","title":"Interval.Date.discrete?/0","type":"function"},{"doc":"Callback implementation for Ecto.Type.embed_as/1 .","ref":"Interval.Date.html#embed_as/1","title":"Interval.Date.embed_as/1","type":"function"},{"doc":"Callback implementation for Ecto.Type.equal?/2 .","ref":"Interval.Date.html#equal?/2","title":"Interval.Date.equal?/2","type":"function"},{"doc":"Callback implementation for Interval.Behaviour.new/1 .","ref":"Interval.Date.html#new/1","title":"Interval.Date.new/1","type":"function"},{"doc":"Callback implementation for Interval.Behaviour.point_compare/2 .","ref":"Interval.Date.html#point_compare/2","title":"Interval.Date.point_compare/2","type":"function"},{"doc":"Callback implementation for Interval.Behaviour.point_step/2 .","ref":"Interval.Date.html#point_step/2","title":"Interval.Date.point_step/2","type":"function"},{"doc":"Callback implementation for Interval.Behaviour.point_valid?/1 .","ref":"Interval.Date.html#point_valid?/1","title":"Interval.Date.point_valid?/1","type":"function"},{"doc":"Callback implementation for Interval.Behaviour.size/1 .","ref":"Interval.Date.html#size/1","title":"Interval.Date.size/1","type":"function"},{"doc":"An interval of point type Elixir.Date","ref":"Interval.Date.html#t:t/0","title":"Interval.Date.t/0","type":"type"},{"doc":"Represents a continuous interval containing Elixir.DateTime","ref":"Interval.DateTime.html","title":"Interval.DateTime","type":"module"},{"doc":"Callback implementation for Interval.Behaviour.discrete?/0 .","ref":"Interval.DateTime.html#discrete?/0","title":"Interval.DateTime.discrete?/0","type":"function"},{"doc":"Callback implementation for Ecto.Type.embed_as/1 .","ref":"Interval.DateTime.html#embed_as/1","title":"Interval.DateTime.embed_as/1","type":"function"},{"doc":"Callback implementation for Ecto.Type.equal?/2 .","ref":"Interval.DateTime.html#equal?/2","title":"Interval.DateTime.equal?/2","type":"function"},{"doc":"Callback implementation for Interval.Behaviour.new/1 .","ref":"Interval.DateTime.html#new/1","title":"Interval.DateTime.new/1","type":"function"},{"doc":"Callback implementation for Interval.Behaviour.point_compare/2 .","ref":"Interval.DateTime.html#point_compare/2","title":"Interval.DateTime.point_compare/2","type":"function"},{"doc":"Callback implementation for Interval.Behaviour.point_step/2 .","ref":"Interval.DateTime.html#point_step/2","title":"Interval.DateTime.point_step/2","type":"function"},{"doc":"Callback implementation for Interval.Behaviour.point_valid?/1 .","ref":"Interval.DateTime.html#point_valid?/1","title":"Interval.DateTime.point_valid?/1","type":"function"},{"doc":"Callback implementation for Interval.Behaviour.size/1 .","ref":"Interval.DateTime.html#size/1","title":"Interval.DateTime.size/1","type":"function"},{"doc":"An interval of point type Elixir.DateTime","ref":"Interval.DateTime.html#t:t/0","title":"Interval.DateTime.t/0","type":"type"},{"doc":"Represents a continuous interval containing Elixir.Decimal","ref":"Interval.Decimal.html","title":"Interval.Decimal","type":"module"},{"doc":"Callback implementation for Interval.Behaviour.discrete?/0 .","ref":"Interval.Decimal.html#discrete?/0","title":"Interval.Decimal.discrete?/0","type":"function"},{"doc":"Callback implementation for Ecto.Type.embed_as/1 .","ref":"Interval.Decimal.html#embed_as/1","title":"Interval.Decimal.embed_as/1","type":"function"},{"doc":"Callback implementation for Ecto.Type.equal?/2 .","ref":"Interval.Decimal.html#equal?/2","title":"Interval.Decimal.equal?/2","type":"function"},{"doc":"Callback implementation for Interval.Behaviour.new/1 .","ref":"Interval.Decimal.html#new/1","title":"Interval.Decimal.new/1","type":"function"},{"doc":"Callback implementation for Interval.Behaviour.point_compare/2 .","ref":"Interval.Decimal.html#point_compare/2","title":"Interval.Decimal.point_compare/2","type":"function"},{"doc":"Callback implementation for Interval.Behaviour.point_step/2 .","ref":"Interval.Decimal.html#point_step/2","title":"Interval.Decimal.point_step/2","type":"function"},{"doc":"Callback implementation for Interval.Behaviour.point_valid?/1 .","ref":"Interval.Decimal.html#point_valid?/1","title":"Interval.Decimal.point_valid?/1","type":"function"},{"doc":"Callback implementation for Interval.Behaviour.size/1 .","ref":"Interval.Decimal.html#size/1","title":"Interval.Decimal.size/1","type":"function"},{"doc":"An interval of point type Elixir.Decimal","ref":"Interval.Decimal.html#t:t/0","title":"Interval.Decimal.t/0","type":"type"},{"doc":"Represents a continuous interval containing Elixir.Float","ref":"Interval.Float.html","title":"Interval.Float","type":"module"},{"doc":"Callback implementation for Interval.Behaviour.discrete?/0 .","ref":"Interval.Float.html#discrete?/0","title":"Interval.Float.discrete?/0","type":"function"},{"doc":"Callback implementation for Ecto.Type.embed_as/1 .","ref":"Interval.Float.html#embed_as/1","title":"Interval.Float.embed_as/1","type":"function"},{"doc":"Callback implementation for Ecto.Type.equal?/2 .","ref":"Interval.Float.html#equal?/2","title":"Interval.Float.equal?/2","type":"function"},{"doc":"Callback implementation for Interval.Behaviour.new/1 .","ref":"Interval.Float.html#new/1","title":"Interval.Float.new/1","type":"function"},{"doc":"Callback implementation for Interval.Behaviour.point_compare/2 .","ref":"Interval.Float.html#point_compare/2","title":"Interval.Float.point_compare/2","type":"function"},{"doc":"Callback implementation for Interval.Behaviour.point_step/2 .","ref":"Interval.Float.html#point_step/2","title":"Interval.Float.point_step/2","type":"function"},{"doc":"Callback implementation for Interval.Behaviour.point_valid?/1 .","ref":"Interval.Float.html#point_valid?/1","title":"Interval.Float.point_valid?/1","type":"function"},{"doc":"Callback implementation for Interval.Behaviour.size/1 .","ref":"Interval.Float.html#size/1","title":"Interval.Float.size/1","type":"function"},{"doc":"An interval of point type Elixir.Float","ref":"Interval.Float.html#t:t/0","title":"Interval.Float.t/0","type":"type"},{"doc":"Represents a discrete interval containing Elixir.Integer","ref":"Interval.Integer.html","title":"Interval.Integer","type":"module"},{"doc":"Callback implementation for Interval.Behaviour.discrete?/0 .","ref":"Interval.Integer.html#discrete?/0","title":"Interval.Integer.discrete?/0","type":"function"},{"doc":"Callback implementation for Ecto.Type.embed_as/1 .","ref":"Interval.Integer.html#embed_as/1","title":"Interval.Integer.embed_as/1","type":"function"},{"doc":"Callback implementation for Ecto.Type.equal?/2 .","ref":"Interval.Integer.html#equal?/2","title":"Interval.Integer.equal?/2","type":"function"},{"doc":"Callback implementation for Interval.Behaviour.new/1 .","ref":"Interval.Integer.html#new/1","title":"Interval.Integer.new/1","type":"function"},{"doc":"Callback implementation for Interval.Behaviour.point_compare/2 .","ref":"Interval.Integer.html#point_compare/2","title":"Interval.Integer.point_compare/2","type":"function"},{"doc":"Callback implementation for Interval.Behaviour.point_step/2 .","ref":"Interval.Integer.html#point_step/2","title":"Interval.Integer.point_step/2","type":"function"},{"doc":"Callback implementation for Interval.Behaviour.point_valid?/1 .","ref":"Interval.Integer.html#point_valid?/1","title":"Interval.Integer.point_valid?/1","type":"function"},{"doc":"Callback implementation for Interval.Behaviour.size/1 .","ref":"Interval.Integer.html#size/1","title":"Interval.Integer.size/1","type":"function"},{"doc":"An interval of point type Elixir.Integer","ref":"Interval.Integer.html#t:t/0","title":"Interval.Integer.t/0","type":"type"},{"doc":"Implementing this protocol allows Interval to infer the implementation to use for a value, which allows you to pass the values to Interval.new/1 without specifying a module option: iex&gt; Interval . new ( left : 1 , right : 2 ) Instead of iex&gt; Interval . new ( module : Interval.Integer , left : 1 , right : 2 ) # or equivalent iex&gt; Interval.Integer . new ( left : 1 , right : 2 ) This functionality is purely for ergonomic reasons, and is not required to be able to define custom intervals, or to use the builtin ones. Explicitly calling Interval.Integer.new/1 could be preferred in certain situations because you know exactly what implementation you are getting.","ref":"Interval.Intervalable.html","title":"Interval.Intervalable","type":"protocol"},{"doc":"Return the Interval.Behaviour implementation to use for this value type","ref":"Interval.Intervalable.html#infer_implementation/1","title":"Interval.Intervalable.infer_implementation/1","type":"function"},{"doc":"","ref":"Interval.Intervalable.html#t:t/0","title":"Interval.Intervalable.t/0","type":"type"},{"doc":"Implements support for auto-implementing Ecto.Type. Example use Interval.Support.EctoTypeType , ecto_type : :numrange","ref":"Interval.Support.EctoType.html","title":"Interval.Support.EctoType","type":"module"},{"doc":"Convert a Postgrex.Range to a struct of type module","ref":"Interval.Support.EctoType.html#from_postgrex_range/2","title":"Interval.Support.EctoType.from_postgrex_range/2","type":"function"},{"doc":"Returns if Interval was compiled with support for Ecto.Type","ref":"Interval.Support.EctoType.html#supported?/0","title":"Interval.Support.EctoType.supported?/0","type":"function"},{"doc":"Convert an Interval struct to a Postgrex.Range .","ref":"Interval.Support.EctoType.html#to_postgrex_range/2","title":"Interval.Support.EctoType.to_postgrex_range/2","type":"function"},{"doc":"Datatype and operations for both discrete and continuous intervals, Inspired by PostgreSQL's range types . Find the documentation at https://hexdocs.pm/interval/","ref":"readme.html","title":"Interval","type":"extras"},{"doc":"The package can be installed by adding interval to your list of dependencies in mix.exs : def deps do [ { :interval , &quot;~&gt; 0.3.2&quot; } ] end","ref":"readme.html#installation","title":"Interval - Installation","type":"extras"},{"doc":"With Ecto The builtin types (Like Interval.DateTime ) can be used as an Ecto.Type out of the box: schema &quot;reservations&quot; do field :period , Interval.DateTime # ... end Integer intervals a = Interval.Integer . new ( left : 1 , right : 4 , bounds : &quot;[]&quot; ) b = Interval.Integer . new ( left : 2 , right : 5 , bounds : &quot;[]&quot; ) assert Interval . contains? ( a , b ) assert Interval . overlaps? ( a , b ) c = Interval . intersection ( a , b ) # [2, 4] d = Interval . union ( a , b ) # [1, 5] DateTime intervals # default bound is &quot;[)&quot; y2022 = Interval.Integer . new ( left : ~U[2022-01-01 00:00:00Z] , right : ~U[2023-01-01 00:00:00Z] ) x = Interval.Integer . new ( left : ~U[2018-07-01 00:00:00Z] , right : ~U[2022-03-01 00:00:00Z] ) Interval . intersection ( y2022 , x ) # %Interval{ # left: {:inclusive, ~U[2022-01-01 00:00:00Z]}, # right: {:exclusive, ~U[2022-03-01 00:00:00Z]} # }","ref":"readme.html#examples","title":"Interval - Examples","type":"extras"},{"doc":"All notable changes to this project will be documented in this file. The format is based on Keep a Changelog , and this project adheres to Semantic Versioning .","ref":"changelog.html","title":"Changelog","type":"extras"},{"doc":"Added Changed Deprecated Removed Fixed Security","ref":"changelog.html#unreleased","title":"Changelog - [Unreleased]","type":"extras"},{"doc":"Added Changed Deprecated Removed Fixed Issue #19. Could not compile when the dependant project did not have Ecto included, which was a bug. Security","ref":"changelog.html#v0-3-2-2022-11-22","title":"Changelog - [v0.3.2] - 2022-11-22","type":"extras"},{"doc":"Added Added type and typespecs for builtin types. Added additional documentation in Interval Changed Deprecated Removed Fixed Security","ref":"changelog.html#v0-3-1-2022-11-21","title":"Changelog - [v0.3.1] - 2022-11-21","type":"extras"},{"doc":"Added Mostly automatic support Ecto.Type (including for builtin interval types) left/1 and right/1 to extract the left and right values from the interval. Builtin Jason.Encoder support. Interval.__using__ option jason_encoder for including encoder. Defaults to true . Interval.to_map/1 to convert an Interval struct to a map suitible for JSON and similar serialization. Interval.Decimal for Decimal support. Changed Interval.__using__ option discrete is now optional, and defaults to false Deprecated Removed Fixed Security","ref":"changelog.html#v0-3-0-2022-11-21","title":"Changelog - [v0.3.0] - 2022-11-21","type":"extras"},{"doc":"Added Allow opting out of built in implementations by configuring :interval, Interval.Float: false Adding Interval.Intervalable protocol, which allows you to define what interval implementation to use for value types. This is purely for ergonomic reasons. Special-case for empty intervals, which doesn't require implementation-specific behaviour. Adding Interval.contains_point?/2 Adding Interval.partition/2 Adding Interval.size/1 Changed Various RuntimeError s handling bad input to a function has been converted to ArgumentError s Point.previous(a) and Point.next(a) became point_step/2 in the Interval.Behaviour . Interval.new/1 now requires a :module option of the specific implementation to use, however the implementation has a new/1 that infers this when creating new intervals. Removed The idea of a &quot;zero&quot; point was removed because it doesn't make sense for all intervals. Removed the Interval.Point protocol in favor of a behaviour for the entire interval. Removed Interval.size/2","ref":"changelog.html#v0-2-0-2022-10-27","title":"Changelog - [v0.2.0] - 2022-10-27","type":"extras"},{"doc":"Added Added Interval.size/2 . Added parameterized typespec Interval.t/1 Changed The internal Endpoint struct has been replaced by a simple 2-tuple. Empty intervals are now represented by two identical exclusive points. Fixed Fixed a bug in Interval.intersection/2 and Interval.union/2 that causes incorrect bounds in some cases.","ref":"changelog.html#v0-1-3-2022-10-12","title":"Changelog - [v0.1.3] - 2022-10-12","type":"extras"},{"doc":"Fixed Fixed a correctness bug in intersection, where intersections between intervals containing unbounded endpoints would be incorrectly computed.","ref":"changelog.html#v0-1-2-2022-10-10","title":"Changelog - [v0.1.2] - 2022-10-10","type":"extras"}]